# PyMIP [![PyPI version][fury-image]][fury-url] [![Build Status][travis-image]][travis-url]
Provides a Python API to manipulate the [MIP][mip] analysis pipeline: setup, starting, monitoring, and parsing output.


## Features

* TODO


## Install for development

```bash
$ pip install --editable .
```


## Contributing
Anyone can help make this project better - read [CONTRIBUTING](CONTRIBUTING.md) to get started!


## License
MIT. See the [LICENSE](LICENSE) file for more details.


[fury-url]: http://badge.fury.io/py/pymip
[fury-image]: https://badge.fury.io/py/pymip.png

[travis-url]: https://travis-ci.org/Clinical-Genomics/pymip
[travis-image]: https://img.shields.io/travis/Clinical-Genomics/pymip.svg?style=flat

[mip]: http://mip-api.readthedocs.org/en/latest/
